@@ -16,6 +16,7 @@ from jinja2 import Template, FileSystemLoader, Environment
 import sqlite3
 import re
 import pickle
+import unidecode
 
 
 class contentFilters():
@@ -112,16 +113,29 @@ class Bucket3():
         self.db_conn.row_factory = sqlite3.Row
         self.render_Q = set()
 
+        # regexp to extract links from html. Compile once, here.
+        regexp_link = r'<a.*(?=href=\"([^\"]*)\")[^>]*>[^<]*</a>'
+        self.re_link_extract = re.compile(regexp_link)
+
     def util_rel_path(self, abs_path):
         abs_path = os.path.abspath(abs_path)  # make sure path is absolute
         return abs_path[len(self.root_dir) + 1:]
 
-    def util_abs_path(self, rel_path):
-        return os.path.join(self.root_dir, rel_path)
+    def util_abs_path(self, *rel_path):
+        return os.path.join(self.root_dir, *rel_path)
 
     def util_txt_abstract(self, txt):
         txt = re.sub('<[^<]+?>', '', txt)
 
+    def util_extract_links(self, html):
+        links = re.findall(self.re_link_extract, html)
+        return links
+
+    def util_slugify(self, str):
+        # Credit: http://stackoverflow.com/a/8366771
+        str = unidecode.unidecode(str.strip()).lower()
+        return re.sub(r'\W+','-',str)
+
     def util_parse_frontmatter(self, txt):
         meta = yaml.load(txt)
         meta['title'] = meta['title'].strip()
@@ -145,9 +159,7 @@ class Bucket3():
                 if 'id' in meta and meta['id']:
                     meta['slug'] = str(meta['id'])
                 else:
-                    # TODO: a "slugify" method is needed here,
-                    # but the md5(txt) will do for now.
-                    meta['slug'] = hashlib.md5(txt).hexdigest()
+                    meta['slug'] = self.util_slugify(meta['title'])
         else:
             if 'id' in meta and meta['id']:
                 meta['slug'] = str(meta['id'])
@@ -475,6 +487,13 @@ class Bucket3():
             for a in post['meta']['attached']:
                 shutil.copy2(os.path.join(os.path.dirname(self.util_abs_path(post['src'])), a), post['meta']['fs_path'])
 
+
+        urls_file = open(self.util_abs_path('log', 'external_links.txt'), 'a')
+        for link in self.util_extract_links(post['html']):
+            urls_file.write('%s\t%s\n' % (post['url'], link))
+        urls_file.close()
+
+
     def render_home(self):
         if self.posts_in_homepage:
             count = self.posts_in_homepage
@@ -576,46 +595,6 @@ class Bucket3():
             f.write(html.encode('utf8'))
             f.close()
 
-    def ___renderArchives(self):
-        idx = idx = self.db_post_get_all(0, 25)
-
-        max_date = idx[0]['_date']
-        min_date = idx[-1]['_date']
-
-        for year in range(max_date.year, min_date.year - 1, -1):
-            recs = [p for p in idx if p['_date'].year == year]
-            if recs:
-                tpl = self.tpl_env.get_template('archive.html')
-                html = tpl.render(index=recs, year=year)
-                f = open(os.path.join(self.html_dir, '%s' % year, 'index.html'), 'w')
-                f.write(html.encode('utf8'))
-                f.close()
-                max_month = recs[0]['_date'].month
-                min_month = recs[-1]['_date'].month
-                for month in range(max_month, min_month - 1, -1):
-                    mposts = [p for p in recs if p['_date'].month == month]
-                    if mposts:
-                        html = tpl.render(index=mposts, year=year, month=month)
-                        f = open(os.path.join(self.html_dir, '%s' % year, str(month), 'index.html' ), 'w')
-                        f.write(html.encode('utf8'))
-                        f.close()
-
-        if not os.path.exists(os.path.join(self.html_dir, 'archive')):
-            os.makedirs(os.path.join(self.html_dir, 'archive'))
-
-        matrix = {}
-        for year in range(max_date.year, min_date.year - 1, -1):
-            matrix[year] = {}
-            for month in range(1, 13):
-                recs = [p for p in idx if p['_date'].year == year and p['_date'].month == month]
-                matrix[year][month] = len(recs)
-
-        tpl = self.tpl_env.get_template('main_archive.html')
-        html = tpl.render(counts=matrix)
-        f = open(os.path.join(self.html_dir, 'archive', 'index.html'), 'w')
-        f.write(html.encode('utf8'))
-        f.close()
-
     def mentions_get(self, url):
         url_hash = hashlib.md5(url).hexdigest()
         path = os.path.join(self.mentions_dir, '%s.yaml' % url_hash)
@@ -626,7 +605,5 @@ class Bucket3():
             return data
         else:
             return None
-
-
 if __name__ == '__main__':
     pass
